Constants class

Constants is a class for holding constant values.

Constructors

Constants()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

isDarkKey → const String
isDarkKey is a String for holding the is_dark_key.
themeBox → const String
themeBox is a String for holding the theme_box.