ThemeModeBuilderConfig class

ThemeModeBuilderConfig is a utility class where you can configure the ThemeModeBuilder and change theme or check if the theme is dark.

Inheritance

Constructors

ThemeModeBuilderConfig()
ThemeModeBuilderConfig factory singleton provider.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispose() → void
Discards any resources used by the object.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

themeStorageService → ThemeStorageService
themeStorageService returns the instance of the ThemeStorageService.
no setter

Static Methods

ensureInitialized({String? subDir}) → Future<void>
ensureInitialized initialized the ThemeStorageService
getThemeMode() → ThemeMode
getThemeMode returns the theme mode based on the saved value.
isDarkTheme() → bool
isDarkTheme checks if the current theme mode is dark or not and returns the value as a bool.
setDark() → Future<void>
setDark changes the theme mode to dark.
setLight() → Future<void>
setLight changes the theme mode to light.
setSystem() → Future<void>
setSystem changes the theme mode to system.
toggleTheme() → Future<void>
toggleTheme toggles the theme between two values.