isDarkTheme static method
isDarkTheme checks if the current theme mode is dark or not and returns
the value as a bool.
Implementation
static bool isDarkTheme() {
return getThemeMode() == ThemeMode.dark;
}
isDarkTheme checks if the current theme mode is dark or not and returns
the value as a bool.
static bool isDarkTheme() {
return getThemeMode() == ThemeMode.dark;
}