ThemeStorageService class

ThemeStorageService is a service used to abstract the complexity of using the shared_preferences package directly to manipulate theme stuff. It gives higher level functions to make everything easier.

Inheritance

Constructors

ThemeStorageService({required SharedPreferences sharedPreferences})
ThemeStorageService constructor, you need to provide the sharedPreferences.

Properties

hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispose() → void
Discards any resources used by the object.
inherited
getThemeMode() → ThemeMode
getThemeMode gets the current theme mode and returns it as a ThemeMode.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
setThemeMode(ThemeMode themeMode) → Future<void>
setThemeMode sets the theme mode based on the provided themeMode.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited